@@ -1,7 +1,7 @@
-from .Model import Model
 import numpy as np
 import pandas as pd
 from scipy import optimize, stats
+from Model import Model
 
 
 class ChangePointModel(Model):
@@ -300,7 +300,7 @@ class ChangePointModel(Model):
         return p, y_fit
     
 
-    def train(self, interval=None):
+    def train(self, df, interval=None):
         """
         Training method for change point models (SLR, 3PC, 3PH, 4P, 5P)
 
@@ -317,9 +317,9 @@ class ChangePointModel(Model):
         """
         if interval is None:
             interval = self.min_interval
-        
         min_available_interval_num = self.interval_tiers[self.min_interval]
-        desired_interval_num = self.interval_tiers[interval]
+        print(min_available_interval_num)
+        desired_interval_num = self.interval_tiers["Hourly"]
 
         if min_available_interval_num > desired_interval_num:
             self.df = self.group_interval(time_interval=interval,
