@@ -2,7 +2,7 @@ import os
 import numpy as np
 import pandas as pd
 import seaborn as sns
-from .ChangePointModel import ChangePointModel
+from ChangePointModel import ChangePointModel
 
 class NMEC:
     """
@@ -52,7 +52,7 @@ class NMEC:
         pass
 
     def model_with_changepoint(self, df: pd, cp_type="SLR"):
-        my_model = ChangePointModel(df, cp_type)
+        my_model = ChangePointModel(df)
         
         if cp_type.upper() in ["3PH", "3PC"]:
             df = my_model.df
@@ -72,14 +72,14 @@ class NMEC:
                 df_occ = my_model.df
                 df_unocc = None
                 
-            train_estimate = my_model.train_SLR(df_occ.dropna().copy())
+            train_estimate = my_model.train(df_occ.dropna().copy())
             
             if df_unocc is not None:
-                train_estimate = my_model.train_SLR(
+                train_estimate = my_model.train(
                     df_unocc.dropna().copy(), train_estimate)
 
             if train_estimate is not None:
-                return {"occupied model": my_model.lm, "unoccupied model": my_model.lm_unocc,
+                return {
                         "data": train_estimate
                         # 'metrics': my_model.metrics(train_estimate)
                         }
@@ -88,7 +88,7 @@ class NMEC:
                     'No Training Estimate, check if Type is SLR, 2P, 3PH, or 3PC')
   
 
-    def example(self, model_type=None):
+    def example(self, model_type="SLR"):
         print("modeling with type", model_type)
 
         df = pd.read_csv(
